@@ -1,8 +1,7 @@
 from copy import deepcopy
 
-from basicsr.utils.registry import METRIC_REGISTRY
-
-from .psnr_ssim import calculate_psnr, calculate_ssim
+from codeformer.basicsr.metrics.psnr_ssim import calculate_psnr, calculate_ssim
+from codeformer.basicsr.utils.registry import METRIC_REGISTRY
 
 __all__ = ["calculate_psnr", "calculate_ssim"]
 
