@@ -1,5 +1,6 @@
 import numpy as np
-from basicsr.utils.matlab_functions import bgr2ycbcr
+
+from codeformer.basicsr.utils.matlab_functions import bgr2ycbcr
 
 
 def reorder_image(img, input_order="HWC"):
